#
# spec file for package gengetopt
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gengetopt
Version:        2.23
Release:        1.14
Summary:        Commandline parser generator
License:        GPL-3.0-or-later
Group:          Development/Languages/C and C++
URL:            https://www.gnu.org/software/gengetopt/
Source0:        https://ftp.gnu.org/gnu/gengetopt/%{name}-%{version}.tar.xz
Source1:        https://ftp.gnu.org/gnu/gengetopt/%{name}-%{version}.tar.xz.sig
Source2:        https://savannah.gnu.org/project/memberlist-gpgkeys.php?group=%{name}&download=1#/%{name}.keyring
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  help2man
BuildRequires:  makeinfo

%description
Gengetopt is a tool to generate C code to parse getopt styled command line
arguments.
It's similar or even more powerful than the well known libpopt but does not
add any run or compile time dependencies to your projects. Moreover
reading/writing the options from/to config files is also supported.

%prep
%autosetup

%build
%configure
%make_build

%install
%make_install

# our system's getopt.h has getopt_long() on board, no need to install sources
rm -rf %{buildroot}%{_datadir}/%{name}
# info's dir file is not auto ignored on some systems
rm -rf %{buildroot}%{_infodir}/dir
# documentation is handled by doc macr
rm -rf %{buildroot}%{_datadir}/doc/%{name}

%check
%make_build check

%post
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info%{ext_info}

%preun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info%{ext_info}

%files
%license COPYING LICENSE
%doc ChangeLog NEWS README THANKS
%doc doc/*.h doc/*.c doc/*.ggo doc/README.example
%{_bindir}/%{name}
%{_infodir}/%{name}.info%{?ext_info}
%{_infodir}/index.info%{?ext_info}
%{_mandir}/man1/%{name}.1%{?ext_man}

%changelog
* Thu Feb 20 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 2.2.3:
  * Gengen and gengetopt are required when building from git. When
    building from tarball, everything works like it did before.
  * Drop IRIX compatibility
  * To mimic behaviour of coreutils, version string is no longer
    part of --help (bug #34400)
  * To mimic behaviour of coreutils, usage is printed before
    purpose in --help bug #34402)
  * Use singular (`[OPTION]...`, `[FILE]...`) instead of plural
    (`[OPTIONS]...`, `[FILES]...`) (bug #34394)
  * Fix spelling of `--unnamed`. `--unamed` still provided for
    backwards compatibility. (bug #34392)
- Drop no longer applying patches:
  * reproducible.patch
  * gengetopt-glibc-license.patch
* Fri Dec 28 2018 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to make package build
  reproducible again (boo#1047218)
* Mon Nov 12 2018 sbrabec@suse.com
- Fix glibc license (savannah#54996):
  * gengetopt-glibc-license.patch
- Add makeinfo to BuildRequires.
* Fri Apr 13 2018 mpluskal@suse.com
- Run spec-cleaner
* Fri Apr 13 2018 ncutler@suse.com
- Fix License line to be in accordance with "SUSE Mapping for spdx.org"
* Sun Mar  5 2017 mpluskal@suse.com
- Update dependencies
- Small packaging cleanup
* Mon Mar 16 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Use url for source
- Add gpg signature
- Correct info scriplet dependencies
* Thu Nov  8 2012 sweet_f_a@gmx.de
- update to gengetopt-2.22.6
  * A compilation problem in Mac OS X has been fixed.
  * The version text directive has been added.
  * The commandline option --strict-hidden has been added.
  * Many bugs have been fixed.
- use xz compressed sources
* Wed Feb  8 2012 puzel@suse.com
- cleanup spec file
* Mon Sep 26 2011 sweet_f_a@gmx.de
- update to gengetopt-2.22.5
  * correctly preprocess the specified usage string
  * handle escaped newline chars correctly
  * initialize enum variables with generated null enum
    value instead of -1
  * generated parser compilable with C++
* Sun Sep 18 2011 sweet_f_a@gmx.de
- minor build fixes and spec file polish
* Mon Apr 11 2011 puzel@novell.com
- use spec-cleaner
* Wed Dec 30 2009 puzel@novell.com
- update to gengetopt-2.22.4
  * removed other gcc compilation warnings on generated files
* Fri Oct 16 2009 puzel@novell.com
- update to gengetopt-2.22.3
  * enum option values can contain + and - (thanks to Papp Gyozo).
  * fixed compilation problems due to macro FIX_UNUSED which was not
    in the right place (thanks to Matthew Junker)
  * --header-output-dir and --src_output-dir to store cmdline.h
    separately from cmdline.c (thanks to Yegor Yefremov)
  * #include <getopt.h> in the generated files, instead of "getopt.h"
  * generated functions use prototypes with char ** instead of
  char *const *
* Sun Jun 14 2009 puzel@novell.com
- update to gengetopt-2.22.2
  * removed further compilation warnings for generated files
  * fixed a compilation problems for files generated with --include-getopt
    with some versions of stdlib.h
  * removed dependency from flex library (that generated problems in
    compilation in open solaris)
  * uses PACKAGE_NAME, if defined, for printing help and version
  * uses --docdir if specified for installing documentation
* Thu Apr 30 2009 puzel@suse.cz
- initial package (version 2.22.1)
